pub struct Vorg<'a> {
data: FontData<'a>,
}Expand description
The VORG (Vertical Origin) table.
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Vorg<'a>
impl<'a> Vorg<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn version(&self) -> MajorMinor
pub fn version(&self) -> MajorMinor
Major/minor version number. Set to 1.0.
Sourcepub fn default_vert_origin_y(&self) -> i16
pub fn default_vert_origin_y(&self) -> i16
The y coordinate of a glyph’s vertical origin, in the font’s design coordinate system, to be used if no entry is present for the glyph in the vertOriginYMetrics array.
Sourcepub fn num_vert_origin_y_metrics(&self) -> u16
pub fn num_vert_origin_y_metrics(&self) -> u16
Number of elements in the vertOriginYMetrics array.
Sourcepub fn vert_origin_y_metrics(&self) -> &'a [VertOriginYMetrics]
pub fn vert_origin_y_metrics(&self) -> &'a [VertOriginYMetrics]
Array of VertOriginYMetrics records, sorted by glyph ID.
pub fn version_byte_range(&self) -> Range<usize> ⓘ
pub fn default_vert_origin_y_byte_range(&self) -> Range<usize> ⓘ
pub fn num_vert_origin_y_metrics_byte_range(&self) -> Range<usize> ⓘ
pub fn vert_origin_y_metrics_byte_range(&self) -> Range<usize> ⓘ